Community — Schematics 0.9.2 documentation

### Navigation

- index
- modules |
- Schematics 0.9.2 documentation »

# Community

Schematics was created in Brooklyn, NY by James Dennis. Since then, the code has been worked on by folks from around the world. If you have ideas, we encourage you to share them!

Special thanks to Hacker School, Plain Vanilla, Quantopian, Apple, Johns Hopkins University, and everyone who has contributed to Schematics.

## Bugs & Features

We track bugs, feature requests, and documentation requests with Github Issues.

## Mailing list

We discuss the future of Schematics and upcoming changes in detail on schematics-dev.

If you’ve read the documentation and still haven’t found the answer you’re looking for, you should reach out to us here too.

## Contributing

If you’re interested in contributing code or documentation to Schematics, please visit the Developer’s Guide for instructions.

### Navigation

- index
- modules |
- Schematics 0.9.2 documentation »